# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['whylogs',
 'whylogs.api',
 'whylogs.api.fugue',
 'whylogs.api.logger',
 'whylogs.api.logger.experimental.multi_dataset_logger',
 'whylogs.api.pyspark.experimental',
 'whylogs.api.reader',
 'whylogs.api.store',
 'whylogs.api.usage_stats',
 'whylogs.api.whylabs',
 'whylogs.api.whylabs.session',
 'whylogs.api.writer',
 'whylogs.core',
 'whylogs.core.constraints',
 'whylogs.core.constraints.factories',
 'whylogs.core.metrics',
 'whylogs.core.model_performance_metrics',
 'whylogs.core.proto',
 'whylogs.core.proto.v0',
 'whylogs.core.utils',
 'whylogs.core.validators',
 'whylogs.core.view',
 'whylogs.datasets',
 'whylogs.datasets.descr',
 'whylogs.experimental',
 'whylogs.experimental.api.logger',
 'whylogs.experimental.constraints_generation',
 'whylogs.experimental.core',
 'whylogs.experimental.core.metrics',
 'whylogs.experimental.extras',
 'whylogs.experimental.performance_estimation',
 'whylogs.experimental.preprocess.embeddings',
 'whylogs.extras',
 'whylogs.migration',
 'whylogs.viz',
 'whylogs.viz.drift',
 'whylogs.viz.enums',
 'whylogs.viz.extensions',
 'whylogs.viz.extensions.reports',
 'whylogs.viz.utils']

package_data = \
{'': ['*'],
 'whylogs.viz': ['html/*',
                 'html/css/*',
                 'html/fonts/*',
                 'html/images/*',
                 'html/js/*',
                 'html/templates/*']}

install_requires = \
['platformdirs>=3.5.0,<4.0.0',
 'protobuf>=3.19.4',
 'requests>=2.27,<3.0',
 'types-requests>=2.30.0.0,<3.0.0.0',
 'whylabs-client>=0.5.1,<1',
 'whylogs-sketching>=3.4.1.dev3']

extras_require = \
{':python_version < "3.8"': ['importlib-metadata<4.3'],
 ':python_version < "4"': ['typing-extensions>=3.10'],
 'all': ['pybars3>=0.9,<0.10',
         'ipython',
         'pandas',
         'boto3>=1.22.13,<2.0.0',
         'mlflow-skinny>=1.26.1,<2.0.0',
         'google-cloud-storage>=2.5.0,<3.0.0',
         'pyarrow>=8.0.0,<13',
         'pyspark>=3.0.0,<4.0.0',
         'Pillow>=9.2.0,<10.0.0',
         'fugue>=0.8.1,<0.9.0'],
 'all:python_version < "3.11"': ['scipy>=1.5',
                                 'scipy>=1.5',
                                 'numpy',
                                 'numpy',
                                 'scikit-learn>=1.0.2,<2.0.0',
                                 'scikit-learn>=1.0.2,<2.0.0'],
 'all:python_version >= "3.11"': ['scipy>=1.9.2',
                                  'scipy>=1.9.2',
                                  'numpy>=1.23.2',
                                  'numpy>=1.23.2',
                                  'scikit-learn>=1.1.2,<2',
                                  'scikit-learn>=1.1.2,<2'],
 'datasets': ['pandas'],
 'docs': ['sphinx',
          'sphinx-autoapi',
          'sphinx-copybutton>=0.5.0,<0.6.0',
          'myst-parser[sphinx]>=0.17.2,<0.18.0',
          'furo>=2022.3.4,<2023.0.0',
          'sphinx-autobuild>=2021.3.14,<2022.0.0',
          'sphinxext-opengraph>=0.6.3,<0.7.0',
          'ipython_genutils>=0.2.0,<0.3.0',
          'nbsphinx>=0.8.9,<0.9.0',
          'nbconvert>=7.0.0,<8.0.0'],
 'docs:python_version >= "3.8" and python_version < "4"': ['sphinx-inline-tabs'],
 'embeddings:python_version < "3.11"': ['numpy',
                                        'numpy',
                                        'scikit-learn>=1.0.2,<2.0.0',
                                        'scikit-learn>=1.0.2,<2.0.0'],
 'embeddings:python_version >= "3.11"': ['numpy>=1.23.2',
                                         'numpy>=1.23.2',
                                         'scikit-learn>=1.1.2,<2',
                                         'scikit-learn>=1.1.2,<2'],
 'fugue': ['fugue>=0.8.1,<0.9.0'],
 'gcs': ['google-cloud-storage>=2.5.0,<3.0.0'],
 'image': ['Pillow>=9.2.0,<10.0.0'],
 'mlflow': ['mlflow-skinny>=1.26.1,<2.0.0'],
 's3': ['boto3>=1.22.13,<2.0.0'],
 'spark': ['pyarrow>=8.0.0,<13', 'pyspark>=3.0.0,<4.0.0'],
 'viz': ['pybars3>=0.9,<0.10', 'ipython', 'Pillow>=9.2.0,<10.0.0'],
 'viz:python_version < "3.11"': ['scipy>=1.5', 'scipy>=1.5', 'numpy', 'numpy'],
 'viz:python_version >= "3.11"': ['scipy>=1.9.2',
                                  'scipy>=1.9.2',
                                  'numpy>=1.23.2',
                                  'numpy>=1.23.2']}

setup_kwargs = {
    'name': 'whylogs',
    'version': '1.2.6.dev0',
    'description': 'Profile and monitor your ML data pipeline end-to-end',
    'long_description': '<img src="https://static.scarf.sh/a.png?x-pxid=bc3c57b0-9a65-49fe-b8ea-f711c4d35b82" /><p align="center">\n<img src="https://i.imgur.com/nv33goV.png" width="35%"/>\n</br>\n\n<h1 align="center">The open standard for data logging\n\n </h1>\n  <h3 align="center">\n   <a href="https://whylogs.readthedocs.io/"><b>Documentation</b></a> &bull;\n   <a href="https://bit.ly/whylogsslack"><b>Slack Community</b></a> &bull;\n   <a href="https://github.com/whylabs/whylogs#python-quickstart"><b>Python Quickstart</b></a> &bull;\n   <a href="https://whylogs.readthedocs.io/en/latest/examples/integrations/writers/Writing_to_WhyLabs.html"><b>WhyLabs Quickstart</b></a>\n </h3>\n\n<p align="center">\n<a href="https://github.com/whylabs/whylogs-python/blob/mainline/LICENSE" target="_blank">\n    <img src="http://img.shields.io/:license-Apache%202-blue.svg" alt="License">\n</a>\n<a href="https://badge.fury.io/py/whylogs" target="_blank">\n    <img src="https://badge.fury.io/py/whylogs.svg" alt="PyPi Version">\n</a>\n<a href="https://github.com/python/black" target="_blank">\n    <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Code style: black">\n</a>\n<a href="https://pepy.tech/project/whylogs" target="_blank">\n    <img src="https://pepy.tech/badge/whylogs" alt="PyPi Downloads">\n</a>\n<a href="bit.ly/whylogs" target="_blank">\n    <img src="https://github.com/whylabs/whylogs-python/workflows/whylogs%20CI/badge.svg" alt="CI">\n</a>\n<a href="https://codeclimate.com/github/whylabs/whylogs-python/maintainability" target="_blank">\n    <img src="https://api.codeclimate.com/v1/badges/442f6ca3dca1e583a488/maintainability" alt="Maintainability">\n</a>\n</p>\n\n## What is whylogs\n\nwhylogs is an open source library for logging any kind of data. With whylogs, users are able to generate summaries of their datasets (called _whylogs profiles_) which they can use to:\n\n1. Track changes in their dataset\n2. Create _data constraints_ to know whether their data looks the way it should\n3. Quickly visualize key summary statistics about their datasets\n\nThese three functionalities enable a variety of use cases for data scientists, machine learning engineers, and data engineers:\n\n- Detect data drift in model input features\n- Detect training-serving skew, concept drift, and model performance degradation\n- Validate data quality in model inputs or in a data pipeline\n- Perform exploratory data analysis of massive datasets\n- Track data distributions & data quality for ML experiments\n- Enable data auditing and governance across the organization\n- Standardize data documentation practices across the organization\n- And more\n\n## Quickstart\n\nInstall whylogs using the pip package manager in a terminal by running:\n\n```\npip install whylogs\n```\n\nThen you can log data in python as simply as this:\n\n```python\nimport whylogs as why\nimport pandas as pd\n\ndf = pd.read_csv("path/to/file.csv")\nresults = why.log(df)\n```\n\nAnd voilà, you now have a whylogs profile. To learn more about what a whylogs profile is and what you can do with it, check out our [docs](https://whylogs.readthedocs.io/en/latest/) and our [examples](https://github.com/whylabs/whylogs/tree/mainline/python/examples).\n',
    'author': 'WhyLabs.ai',
    'author_email': 'support@whylabs.ai',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://docs.whylabs.ai',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7.1,<4',
}


setup(**setup_kwargs)
